==> advchk_1.10.orig.tar.gz: advchk-1.10/advchk-addfeeds.sh <==
#!/bin/sh
####
##      advchk v1.10 :: reads advisories so you don't have to
#       Copyright (c) 2006-2007 Stephan Schmieder, http://advchk.unixgu.ru

function notFound {
        echo "Can't find advchk in path and cwd!" 1>&2
        exit 1
}

PATH="~/bin:$PATH:."
for i in http://feeds.sophos.com/en/rss2_0-sophos-latest-viruses.xml\
         http://newsroom.cisco.com/data/syndication/rss1/SecurityAdvisories_20.xml\
         http://uk.trendmicro-europe.com/enterprise/security_info/rssinfo.php\
         http://www.astalavista.com/feed/news_headlines_en.xml\
         http://www.cyberworlds.com/CSA.xml\
         http://www.debian.org/security/dsa-long\
         http://www.freebsd.org/security/advisories.rdf\
         http://www.linuxsecurity.com/static-content/linuxsecurity_advisories.rss\
         http://www.mcert.de/rss/mcert-rss.xml\
         http://www.microsoft.com/technet/security/advisory/RssFeed.aspx?securityadvisory\
         http://www.my-etrust.com/alertservice/pg.aspx?f=vul\
         http://www.net-security.org/dl/bck/advi.rss\
         http://www.net-security.org/dl/bck/vuln.rss\
         http://www.netbsd.org/Security/rss-advisories.xml\
         http://www.novell.com/newsfeeds/rss/securityPatches.xml\
         http://www.securiteam.com/securiteam.rss\
         http://www.securityfocus.com/rss/vulnerabilities.xml\
         http://www.us-cert.gov/channels/alerts.rdf\
         http://www.us-cert.gov/channels/techalerts.rdf\
         http://packetstormsecurity.org/advisories.xml\
         http://www.first.org/newsroom/globalsecurity/rss.xml\
         http://cert.belnet.be/rss.php\
         http://groups.google.de/group/django-announce/feed/rss_v2_0_msgs.xml?num=50\
         http://groups.google.com/group/rubyonrails-security/feed/rss_v2_0_msgs.xml?num=50\
         http://www.xramp.com/securityalerts/rss.do;
do
        advchk -a "$i" || notFound
done
# german feeds
#        http://CERT.Uni-Stuttgart.DE/ticker/rus-cert-elsewhere.rdf\
#        http://groups.google.com/group/de.comp.security.misc/feed/rss_v2_0_topics.xml\
#        http://cert.uni-stuttgart.de/ticker/rus-cert.rdf\

==> advchk_2.10.orig.tar.gz: advchk-2.10/advchk-addfeeds.sh <==
#!/bin/sh
####
##      advchk v2.10 :: reads advisories so you don't have to
#       Copyright (c) 2006-2008 Stephan Schmieder, http://unixgu.ru

notFound () {
        echo "Can't find advchk in path and cwd!" 1>&2
        exit 1
}

export PATH="$HOME/bin:$PATH:."
for i in http://feeds.sophos.com/en/rss2_0-sophos-latest-viruses.xml\
         http://newsroom.cisco.com/data/syndication/rss1/SecurityAdvisories_20.xml\
         http://uk.trendmicro-europe.com/enterprise/security_info/rssinfo.php\
         http://www.astalavista.com/feed/news_headlines_en.xml\
         http://www.cyberworlds.com/CSA.xml\
         http://www.debian.org/security/dsa-long\
         http://www.freebsd.org/security/advisories.rdf\
         http://www.linuxsecurity.com/static-content/linuxsecurity_advisories.rss\
         http://www.mcert.de/rss/mcert-rss.xml\
         http://www.microsoft.com/technet/security/advisory/RssFeed.aspx?securityadvisory\
         http://www.my-etrust.com/alertservice/pg.aspx?f=vul\
         http://www.net-security.org/dl/bck/advi.rss\
         http://www.net-security.org/dl/bck/vuln.rss\
         http://www.netbsd.org/Security/rss-advisories.xml\
         http://www.novell.com/newsfeeds/rss/securityPatches.xml\
         http://www.securiteam.com/securiteam.rss\
         http://www.securityfocus.com/rss/vulnerabilities.xml\
         http://www.us-cert.gov/channels/alerts.rdf\
         http://www.us-cert.gov/channels/techalerts.rdf\
         http://packetstormsecurity.org/advisories.xml\
         http://www.first.org/newsroom/globalsecurity/rss.xml\
         http://cert.belnet.be/rss.php\
         http://groups.google.de/group/django-announce/feed/rss_v2_0_msgs.xml?num=50\
         http://groups.google.com/group/rubyonrails-security/feed/rss_v2_0_msgs.xml?num=50\
         http://www.microsoft.com/technet/security/bulletin/secrss.aspx\
         http://www.nessus.org/rss-plugins.xml\
         http://www.webappsec.org/rss/websecurity.rss\
         http://CERT.Uni-Stuttgart.DE/ticker/rus-cert-elsewhere.rdf\
         http://groups.google.com/group/de.comp.security.misc/feed/rss_v2_0_topics.xml\
         http://cert.uni-stuttgart.de/ticker/rus-cert.rdf\
         http://www.xramp.com/securityalerts/rss.do;
do
        advchk -a "$i" || notFound
done
#http://www.microsoft.com/germany/technet/sicherheit/bulletins/secrss.xml\
